@@ -586,6 +586,21 @@ class HivePartitioningOptions(object):
     def source_uri_prefix(self, value):
         self._properties["sourceUriPrefix"] = value
 
+    @property
+    def require_partition_filter(self):
+        """Optional[bool]: If set to true, queries over the partitioned table require a
+        partition filter that can be used for partition elimination to be
+        specified.
+
+        See
+        https://cloud.google.com/bigquery/docs/reference/rest/v2/tables#HivePartitioningOptions.FIELDS.mode
+        """
+        return self._properties.get("requirePartitionFilter")
+
+    @require_partition_filter.setter
+    def require_partition_filter(self, value):
+        self._properties["requirePartitionFilter"] = value
+
     def to_api_repr(self):
         """Build an API representation of this object.
 
@@ -745,6 +760,23 @@ class ExternalConfig(object):
         prop = self._properties.get("schema", {})
         return [SchemaField.from_api_repr(field) for field in prop.get("fields", [])]
 
+    @property
+    def connection_id(self):
+        """Optional[str]: [Experimental] ID of a BigQuery Connection API
+        resource.
+
+        .. WARNING::
+
+           This feature is experimental. Pre-GA features may have limited
+           support, and changes to pre-GA features may not be compatible with
+           other pre-GA versions.
+        """
+        return self._properties.get("connectionId")
+
+    @connection_id.setter
+    def connection_id(self, value):
+        self._properties["connectionId"] = value
+
     @schema.setter
     def schema(self, value):
         prop = value
