@@ -74,17 +74,11 @@ class TestExternalConfig(unittest.TestCase):
         ec.autodetect = True
         ec.ignore_unknown_values = False
         ec.compression = "compression"
+        ec.connection_id = "path/to/connection"
         ec.schema = [schema.SchemaField("full_name", "STRING", mode="REQUIRED")]
 
         exp_schema = {
-            "fields": [
-                {
-                    "name": "full_name",
-                    "type": "STRING",
-                    "mode": "REQUIRED",
-                    "description": None,
-                }
-            ]
+            "fields": [{"name": "full_name", "type": "STRING", "mode": "REQUIRED"}]
         }
         got_resource = ec.to_api_repr()
         exp_resource = {
@@ -94,10 +88,17 @@ class TestExternalConfig(unittest.TestCase):
             "autodetect": True,
             "ignoreUnknownValues": False,
             "compression": "compression",
+            "connectionId": "path/to/connection",
             "schema": exp_schema,
         }
         self.assertEqual(got_resource, exp_resource)
 
+    def test_connection_id(self):
+        ec = external_config.ExternalConfig("")
+        self.assertIsNone(ec.connection_id)
+        ec.connection_id = "path/to/connection"
+        self.assertEqual(ec.connection_id, "path/to/connection")
+
     def test_schema_None(self):
         ec = external_config.ExternalConfig("")
         ec.schema = None
